@@ -26,10 +26,9 @@
     exports schemacrawler.tools.options;
     exports schemacrawler.tools.registry;
     exports schemacrawler.tools.utility;
-    exports schemacrawler.loader.attributes;
-    exports schemacrawler.loader.attributes.model;
-    exports schemacrawler.loader.counts;
-    exports schemacrawler.loader.weakassociations;
+    exports schemacrawler.ermodel.model;
+    exports schemacrawler.ermodel.utility;
+    exports schemacrawler.loader.utility;
 
     opens schemacrawler.schema to tools.jackson.databind;
 
